fastRdm: Fit diffusion model

Description Usage Arguments Value Examples

View source: R/fastdm.R

Description

Specify diffusion model and fit it to response time (RT) data using the fast-dm library (v30.2)

Usage

1

Arguments

formula

model formula (see details).

dat

data.frame or named list consisting of many data.frames. Each data.frame must contain the following variables: a numeric vector TIME, containing RT from a respective trial a boolean/integer vector RESPONSE, containing the given response FALSE/0 or TRUE/1 from the respective trial

method

character, optimization method: Kolmogorov-Smirnov (ks), Maximum Likelihood (ml), or Chi-Square (cs).

precision

numeric, approximate precision of parameter estimates in decimals.

wd_fastdm

character, working directory containing fast-dm executable (defaults to 'path').

res_prefix

character, prefix of temporary data files.

removeTempFiles

logical, should the temporary files used by fast-dm should be kept (FALSE) or removed (TRUE).

Value

data.frame, parameter estimates and fit statistics for each fitted RT distribution.

Examples

1
2
3
4
5
6
## Not run: 
path <- "./inst/binaries_30_2"
dat <- rdm(100, a=1, zr=.5, v=1.25, t0=0, N = 10)
out <- fastdm(~ zr*.5 + szr*0 + sv*0 + st0*0 + d*0, dat, method = "ks", precision = 3, res_prefix = "ID")

## End(Not run)

waidschrat/fastRdm documentation built on Nov. 5, 2019, 12:06 p.m.