Description Usage Arguments Value Examples
Specify diffusion model and fit it to response time (RT) data using the fast-dm library (v30.2)
1 | fastRdm()
|
formula |
model formula (see details). |
dat |
data.frame or named list consisting of many data.frames. Each data.frame must contain the following variables: a numeric vector TIME, containing RT from a respective trial a boolean/integer vector RESPONSE, containing the given response FALSE/0 or TRUE/1 from the respective trial |
method |
character, optimization method: Kolmogorov-Smirnov (ks), Maximum Likelihood (ml), or Chi-Square (cs). |
precision |
numeric, approximate precision of parameter estimates in decimals. |
wd_fastdm |
character, working directory containing fast-dm executable (defaults to 'path'). |
res_prefix |
character, prefix of temporary data files. |
removeTempFiles |
logical, should the temporary files used by fast-dm should be kept (FALSE) or removed (TRUE). |
data.frame, parameter estimates and fit statistics for each fitted RT distribution.
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.